@@ -23,24 +23,15 @@ class _Credentials:
 
         mode = os.environ.get('MODE')
 
-        if mode:  # .venv was already read in other project
-            self.host = os.environ["DB_HOST"]
-            self.port = os.environ["DB_PORT"]
-            self.database = os.environ["DB_DATABASE"]
-            self.user = os.environ["DB_USER"]
-            self.pw = os.environ["DB_PASSWORD"]
+        if not mode:
+            load_dotenv()
+        mode = os.environ['MODE']
 
-        else:  # read .venv from this project
-
-            load_dotenv(Path(Path(__file__).parent.parent.parent / '.env'))
-
-            mode = os.environ['MODE']
-
-            self.host = os.environ[f"DB_HOST_{mode}"]
-            self.port = os.environ[f"DB_PORT_{mode}"]
-            self.database = os.environ[f"DB_DATABASE_{mode}"]
-            self.user = os.environ[f"DB_USER_{mode}"]
-            self.pw = os.environ[f"DB_PASSWORD_{mode}"]
+        self.host = os.environ[f"DB_HOST_{mode}"]
+        self.port = os.environ[f"DB_PORT_{mode}"]
+        self.database = os.environ[f"DB_DATABASE_{mode}"]
+        self.user = os.environ[f"DB_USER_{mode}"]
+        self.pw = os.environ[f"DB_PASSWORD_{mode}"]
 
 
 _cred = _Credentials()
